import re

from operator import methodcaller
from scenedata import definitions


def parse(filename):
    """ parse a scene release string and return a dictionary of parsed values."""
    screensize = re.compile('(720p|1080p)')
    format_ = re.compile(
        'CAM|TS|TELESYNC|(DVD|BD)?SCR|DDC|R5[\.\s]LINE|R5|(DVD|HD|BR|BD|WEB)Rip|DVDR|(HD|PD)TV|WEB-?DL|BluRay')
    year = re.compile('(1|2)\d{3}')
    series = re.compile('s\d{1,3}e\d{1,3}', re.I)
    group = re.compile('[A-Za-z0-9]+$', re.I)
    video = re.compile('MP4|NTSC|PAL|[xh][\.\s]?264')
    audio = re.compile('AAC2[\.\s]0|AAC|AC3|DTS|DD5')
    edition = re.compile(
        'UNRATED|DC|(Directors|EXTENDED)[\.\s](CUT|EDITION)|EXTENDED|3D|2D|\bNF\b',
         re.I)
    tags = re.compile(
        'COMPLETE|LiMiTED|iNTERNAL|UNCUT|FESTIVAL|DUBBED|SUBBED|WS', re.I)
    release = re.compile(
        'REAL[\.\s]PROPER|REMASTERED|PROPER|REPACK|READNFO|READ[\.\s]NFO|DiRFiX|NFOFiX', re.I)
    subtitles = re.compile(
        'MULTi(SUBS)?|NORDiC|DANiSH|SWEDiSH|RUSSIAN|NORWEGiAN|GERMAN|iTALiAN|FRENCH|SPANiSH|SWESUB', re.I)

    title = filename
    attrs = {'screenSize': screensize,
             'format': format_,
             'year': year,
             'series': series,
             'release_group': group,
             'video': video,
             'audio': audio,
             'edition': edition,
             'tags': tags,
             'release': release,
             'subtitles': subtitles
             }
    data = {}
    for attr in attrs:
        match = methodcaller('search', filename)(attrs[attr])
        if match:
            matched = methodcaller('group')(match)
            data[attr] = matched
            title = re.sub(matched, '', title)
    temptitle = title.replace('.', ' ').strip('-').strip()
    data['title'] = re.sub('\s{2,}', ' ', temptitle)
    if 'series' in data:
        s, e = re.split('e|E', data['series'])
        # use lstrip to remove leading zeros
        data['season'] = s[1:].lstrip('0')
        data['episode'] = e.lstrip('0')
        del data['series']
    return data


def explain(tag):
    """explain scene release tags in plain english"""
    return definitions[tag.lower()]



# -*- coding: utf-8 -*-
from collections import defaultdict

definitions = defaultdict(lambda: "Unknown", {
    'cam': 'a theater rip usually done with a digital video camera',
    'ts': 'A theater rip done with digital video camera with an external audio source',
    'tc': 'A telecine machine copies the film digitally from the reels',
    'dvdscr': ' transferred off a DVD sent to retail stores for promotional use',
    'retail': '',
    'hdtv': 'Digital recording from high definition source',
    'sdtv': '',
    'dvdr': '',
    'proper': '',
    'limited': '',
    'stv': '',
    'dc': 'Director\'s cut',
    'extended': '',
    'remastered': '',
    'unrated': '',
    'repack': '',
    'dubbed': '',
    'dvdrip': 'A copy of the final released DVD',
    'vhsrip': 'transferred off a retail VHS'
}
)



from setuptools import find_packages
from setuptools import setup

try:
    from pypandoc import convert
    read_md = lambda f: convert(f, 'rst')
except ImportError:
    print(
        "warning: pypandoc module not found, could not convert Markdown to RST")
    read_md = lambda f: open(f, 'r').read()

setup(
    name='videoscene',
    version="0.2.0",
    description='Parse scene release tags',
    long_description=read_md('README.md'),
    keywords='scene release tags',
    author='Walid Saad',
    author_email='walid.sa3d@gmail.com',
    url='http://github.com/walidsa3d/videoscene',
    packages=find_packages(),
    package_data={'': ['LICENSE']},
    include_package_data=True,
    test_suite="nose.collector",
    license="MIT",
    zip_safe=False,
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: Unix',
        'Programming Language :: Python :: 2.7',
        'Topic :: Utilities'
    ]
)
